@@ -4,5 +4,5 @@ from . import views
 
 app_name = 'generic_search'
 urlpatterns = [
-    path('', views.GeneralSearch.as_view(), name='general_search'),
+    path('', views.GeneralSearch.as_view(), name='generic_search'),
 ]
